pub enum Error {
Http(Error),
Resend(ErrorResponse),
Parse {
message: String,
source: Option<Box<dyn Error + Send + Sync>>,
},
Other(String),
RateLimit {
ratelimit_limit: Option<u64>,
ratelimit_remaining: Option<u64>,
ratelimit_reset: Option<u64>,
},
}Expand description
Error type for operations of a Resend client.
Variants
Http(Error)
Errors that may occur during the processing an HTTP request.
Resend(ErrorResponse)
Errors that may occur during the processing of the API request.
Parse
Errors that may occur during the parsing of an API response.
Other(String)
Other more generic errors
RateLimit
Detailed rate limit error. For the old error variant see
types::ErrorKind::RateLimitExceeded.