pub enum EmailEvent {
Bounced,
Canceled,
Clicked,
Complained,
Delivered,
DeliveryDelayed,
Failed,
Opened,
Queued,
Scheduled,
Sent,
}Expand description
Strongly typed last_event.
https://resend.com/docs/dashboard/emails/introduction#understand-email-events
Variants
Bounced
The recipient’s mail server rejected the email.
Canceled
The scheduled email was canceled (by user).
Clicked
The recipient clicked on a link in the email.
Complained
The email was successfully delivered to the recipient’s mail server, but the recipient marked it as spam.
Delivered
Resend successfully delivered the email to the recipient’s mail server.
DeliveryDelayed
The email couldn’t be delivered to the recipient’s mail server because a temporary issue occurred. Delivery delays can occur, for example, when the recipient’s inbox is full, or when the receiving email server experiences a transient issue.
Failed
The email failed to be sent.
Opened
The recipient opened the email.
Queued
The email created from Broadcasts or Batches is queued for delivery.
Scheduled
The email is scheduled for delivery.
Sent
The email was sent successfully.