pub enum TopicVisibility {
Public,
Private,
}Variants
Public
Only contacts who are opted in to the topic can see it on the unsubscribe page.
Private
All contacts can see the topic on the unsubscribe page.