pub struct CreateBroadcastOptions { /* private fields */ }Expand description
Details of a new Broadcast.
Implementations
Sourceimpl CreateBroadcastOptions
impl CreateBroadcastOptions
Sourcepub fn new(audience_id: &str, from: &str, subject: &str) -> Self
pub fn new(audience_id: &str, from: &str, subject: &str) -> Self
Creates a new CreateBroadcastOptions.
audience_id: The ID of the audience you want to send to.from: To include a friendly name, use the format"Your Name <sender@domain.com>".subject: Email subject.
Sourcepub fn with_reply(self, to: &str) -> Self
pub fn with_reply(self, to: &str) -> Self
Appends reply_to address to the broadcast.
Sourcepub fn with_reply_multiple(self, to: &[String]) -> Self
pub fn with_reply_multiple(self, to: &[String]) -> Self
Appends multiple reply_to addresses to the broadcast.
Sourcepub fn with_text(self, text: &str) -> Self
pub fn with_text(self, text: &str) -> Self
Adds or overwrites the plain text version of the message.
Sourcepub fn with_send(self, send: bool) -> Self
pub fn with_send(self, send: bool) -> Self
When set to true, the broadcast will be sent or scheduled (if scheduled_at is
provided) without requiring a separate call to the
crate::broadcasts::BroadcastsSvc::send endpoint.
Sourcepub fn with_scheduled_at(self, scheduled_at: &str) -> Self
pub fn with_scheduled_at(self, scheduled_at: &str) -> Self
Schedule email to be sent later. The date should be in language natural (e.g.: in 1 min) or ISO 8601 format (e.g: 2024-08-05T11:52:01.858Z).