pub struct CreateDomainOptions { /* private fields */ }Expand description
Details of a new Domain.
Implementations
Sourceimpl CreateDomainOptions
impl CreateDomainOptions
Sourcepub fn new(name: &str) -> Self
pub fn new(name: &str) -> Self
Creates a new CreateDomainOptions.
name: The name of the domain you want to create.
Sourcepub fn with_region(self, region: impl Into<Region>) -> Self
pub fn with_region(self, region: impl Into<Region>) -> Self
The region where the email will be sent from.
Sourcepub fn with_custom_return_path(
self,
custom_return_path: impl Into<String>,
) -> Self
pub fn with_custom_return_path( self, custom_return_path: impl Into<String>, ) -> Self
For advanced use cases, choose a subdomain for the Return-Path address.
The custom return path is used for SPF authentication, DMARC alignment, and handling
bounced emails. Defaults to send (i.e., send.yourdomain.tld). Avoid setting values
that could undermine credibility (e.g. testing), as they may be exposed to recipients.
pub fn with_open_tracking(self, open_tracking: bool) -> Self
pub fn with_click_tracking(self, click_tracking: bool) -> Self
pub fn with_tracking_subdomain( self, tracking_subdomain: impl Into<String>, ) -> Self
pub fn with_tls(self, tls: Tls) -> Self
pub fn with_capabilities(self, capabilities: Value) -> Self