CreateEmailBaseOptions

Struct CreateEmailBaseOptions 

pub struct CreateEmailBaseOptions { /* private fields */ }
All requisite components and associated data to send an email.

See docs.

Implementations

Source

impl CreateEmailBaseOptions

pub fn new<T, A>( from: impl Into<String>, to: T, subject: impl Into<String>, ) -> Self
where T: IntoIterator<Item = A>, A: Into<String>,

Creates a new CreateEmailBaseOptions.

  • from: Sender email address. To include a friendly name, use the format: Your Name <sender@domain.com>.
  • to: Recipient email addresses. Max 50.
  • subject: Email subject.
pub fn with_html(self, html: &str) -> Self

Adds or overwrites the HTML version of the message.

pub fn with_text(self, text: &str) -> Self

Adds or overwrites the plain text version of the message.

pub fn with_bcc(self, address: &str) -> Self

Attaches bcc recipient email address.

pub fn with_cc(self, address: &str) -> Self

Attaches cc recipient email address.

pub fn with_reply(self, to: &str) -> Self

Adds another reply_to address to the email.

pub fn with_reply_multiple(self, to: &[String]) -> Self

Append multiple reply_to addresses to the email.

pub fn with_header(self, name: &str, value: &str) -> Self

Adds an email header.

pub fn with_attachment(self, file: impl Into<CreateAttachment>) -> Self

Adds another attachment.

Limited to max 40mb per email.

pub fn with_attachments( self, new_attachments: impl IntoIterator<Item = impl Into<CreateAttachment>>, ) -> Self

Adds multiple attachments.

Limited to max 40mb per email.

pub fn with_tag(self, tag: impl Into<Tag>) -> Self

Adds additional email tag.

pub fn with_template(self, template: impl Into<EmailTemplate>) -> Self

Adds the template to use for the email.

pub fn with_topic(self, topic_id: &str) -> Self

Sets the topic ID to receive the email.

pub fn with_scheduled_at(self, scheduled_at: &str) -> Self

Schedule email to be sent later. The date should be in ISO 8601 format (e.g: 2024-08-05T11:52:01.858Z).

pub fn with_idempotency_key(self, idempotency_key: &str) -> Idempotent<Self>