pub struct Email {Show 13 fields
pub id: EmailId,
pub message_id: Option<String>,
pub from: String,
pub to: Vec<String>,
pub subject: String,
pub created_at: String,
pub html: Option<String>,
pub text: Option<String>,
pub bcc: Vec<String>,
pub cc: Vec<String>,
pub reply_to: Option<Vec<String>>,
pub last_event: EmailEvent,
pub scheduled_at: Option<String>,
}Expand description
Received email.
Fields
id: EmailIdThe ID of the email.
message_id: Option<String>RFC Message-ID header value for the email.
from: StringSender email address.
to: Vec<String>Recipient email address.
subject: StringThe subject line of the email.
created_at: StringThe date and time the email was created.
html: Option<String>The HTML body of the email.
text: Option<String>The plain text body of the email.
bcc: Vec<String>The email addresses of the blind carbon copy recipients.
cc: Vec<String>The email addresses of the carbon copy recipients.
reply_to: Option<Vec<String>>The email addresses to which replies should be sent.
last_event: EmailEventThe status of the email.
scheduled_at: Option<String>The scheduled send time of the email.